summaryrefslogtreecommitdiff
path: root/subplot
diff options
context:
space:
mode:
authorLars Wirzenius <liw@liw.fi>2022-07-03 16:55:08 +0300
committerLars Wirzenius <liw@liw.fi>2022-07-03 16:55:32 +0300
commit141f1ea6609d8ad9686f76aaea0a669fc04ba7e1 (patch)
treeb18f53302331355a5ce9ccfc47a1eea76244d902 /subplot
parent867fe49385d89177bf84af40cee3663b23a7aefc (diff)
downloadriki-141f1ea6609d8ad9686f76aaea0a669fc04ba7e1.tar.gz
chore: rename project to riki
It's a subset of ikiwiki and r for rust. Thank you, Daniel Silverstone, for the inspiration for the name. Sponsored-by: author
Diffstat (limited to 'subplot')
-rw-r--r--subplot/riki.rs (renamed from subplot/rikiwiki.rs)12
-rw-r--r--subplot/riki.yaml (renamed from subplot/rikiwiki.yaml)4
2 files changed, 8 insertions, 8 deletions
diff --git a/subplot/rikiwiki.yaml b/subplot/riki.yaml
index 15181af..a95ec57 100644
--- a/subplot/rikiwiki.yaml
+++ b/subplot/riki.yaml
@@ -1,7 +1,7 @@
-- given: "an installed rikiwiki"
+- given: "an installed riki"
impl:
rust:
- function: install_rikiwiki
+ function: install_riki
- then: "AST of {first} matches that of {second}"
impl:
diff --git a/subplot/rikiwiki.rs b/subplot/riki.rs
index f6aea97..2b9cb7e 100644
--- a/subplot/rikiwiki.rs
+++ b/subplot/riki.rs
@@ -5,11 +5,11 @@ use subplotlib::steplibrary::datadir::Datadir;
#[step]
#[context(Runcmd)]
-fn install_rikiwiki(context: &ScenarioContext) {
- // The RIKIWIKI_DIR variable can be set to test an installed
- // rikiwiki rather than the one built from the source tree.
- if let Some(bindir) = std::env::var_os("RIKIWIKI_DIR") {
- println!("Found RIKIWIKI_DIR environment variable, using that");
+fn install_riki(context: &ScenarioContext) {
+ // The RIKI_DIR variable can be set to test an installed riki
+ // rather than the one built from the source tree.
+ if let Some(bindir) = std::env::var_os("RIKI_DIR") {
+ println!("Found RIKI_DIR environment variable, using that");
context.with_mut(
|rc: &mut Runcmd| {
rc.prepend_to_path(bindir);
@@ -18,7 +18,7 @@ fn install_rikiwiki(context: &ScenarioContext) {
false,
)?;
} else {
- let target_exe = env!("CARGO_BIN_EXE_rikiwiki");
+ let target_exe = env!("CARGO_BIN_EXE_riki");
let target_path = Path::new(target_exe);
let target_path = target_path.parent().ok_or("No parent?")?;